/*
 
 //This file is licensed under the terms of the CC-LGPL
 
 CL_rlp_letter_test.pov
 
 Here's a demonstration of how you might use the user letter adjustment array.   
 
 CL_letter_adjust is defined and default filled within CL_rlp_make_text_string_set as 
 #declare CL_letter_adjust = array[5][100]{{0,...,0},...,{1,...,1},{0,...,0}};
 If you do have more than 100 characters in your string, you will need to extend it.
 
*/
  ////
 //   example   //
//_____________//     
#global_settings{charset utf8 assumed_gamma 1.0}  
//
#include "colors.inc" 
#include "rlp.inc"
#include "CL_rlp_capital_letters_160714.inc" 
//
CL_rlp_make_text_string_set(1)   
#declare CL_debug_lines = 1;    // Get the bounding boxes and some text messages.
//*****************************************************************************************
// Fiddle with this. 1 - 7
#declare string_choose = 7;
//*****************************************************************************************
#switch(string_choose)
  #case(1) 
// A slightly wierder LaTeX logo, including letter rotations, with a lot of adjustment using CL_letter_adjust.
// Note that the bounding box is wrong because of the letter rotations, which are ignored in its calculation.       
    #declare camera_z_distance = 25;
    #declare camera_y_height   = 1;
    #declare CL_set_string     = "LATEX" 
    #declare CL_letter_adjust  = array[5][ 5]{{ 0 ,-1  ,-0.2,-0.3,-0.3},   // Shift x
                                              { 0 , 1  , 0  ,-0.8, 0  },   // Shift y
                                              { 0 , 0  , 0  , 0  , 0  },   // Shearing
                                              { 1 , 0.8, 1  , 1  , 1  },   // Scaling
                                              { 0 , 10 , 0  ,-5  , 0  }}   // Rotation
  #break
//
  #case(2)
// A superscript and a subscript, adjusted with negative space: |, (= -0.5) |! (= -0.2)  
// Note that the calculated bounding box for the object is wrong because it it calculated 
// on the last character on the string, which is the 3. Could add a space after to fix it.                                          
    #declare camera_z_distance = 15;
    #declare camera_y_height   = 1;
    #declare CL_set_string     = "#x^2|,|,_3 |!|!"   // Trailing spaces are to fix the bounding box                                    
//
  #break
//
  #case(3)
// A superscript and a subscript, adjusted using CL_letter_adjust                                             
// Note that the calculated bounding box for the object is wrong because it it calculated 
// on the last character on the string, which is the 3.                                          
  #declare CL_letter_adjust    = array[5][11]{{ 0 , 0  , 0  , 0  , 0 ,-1 , 0 , 0 , 0 , 0 , 0 },
                                              { 0 , 0  , 0  , 0  , 0 , 0 , 0 , 0 , 0 , 0 , 0 },
                                              { 0 , 0  , 0  , 0  , 0 , 0 , 0 , 0 , 0 , 0 , 0 },
                                              { 1 , 1  , 1  , 1  , 1 , 1 , 0 , 0 , 0 , 0 , 0 },
                                              { 0 , 0  , 0  , 0  , 0 , 0 , 0 , 0 , 0 , 0 , 0 }}
    #declare camera_z_distance = 15;
    #declare camera_y_height   = 1;
    #declare CL_set_string     = "#x^2_3 |!|!"
//
  #break                                       
//
  #case(4)
// A multi letter superscript, adjusted using letter adjust. Last character is the 2, i.e. the second level super script.                                             
  #declare CL_letter_adjust    = array[5][12]{
                                  { 0 , 0  , 0  , 0 , 0 , 0 , 0  , 0  , 0  ,-0.5, 0  ,-0.1},  // Kern (x move) -ve to left
                                  { 0 , 0  , 0  , 0 , 0 , 0 , 0  ,0.7 , 0  ,-0.7, 0  ,-0.6},  // Raise (y move) +ve up
                                  { 0 , 0  , 0  , 0 , 0 , 0 , 0  , 0  , 0  , 0  , 0  , 0  },  // Shear. 0.2 - 0.4 goes to the right. -ve to the left.
                                  { 1 , 1  , 1  , 1 , 1 , 1 , 1  ,0.6 , 1  , 1  , 1  , 0.9},  // Scaling factor. Default 1. Superscripts have been scaled by 0.6.
                                  { 0 , 0  , 0  , 0 , 0 , 0 , 0  , 0  , 0  , 0  , 0  , 0  }}  // Rotate. Don't unless you really want to. May need other adjustments.
    #declare camera_z_distance = 20;
    #declare camera_y_height   = 1;
    #declare CL_set_string     = "#e^-^x^2^/^2";
//
  #break                                       
//
  #case(5)
// Multi-level superscript
  #declare CL_letter_adjust    = array[5][ 6]{{ 0 , 0  , 0  , 0  , 0   , 0    },
                                              { 0 , 0  , 0  , 0  , 1.6 , 1.95 },
                                              { 0 , 0  , 0  , 0  , 0   , 0    },
                                              { 1 , 1  , 1  , 1  , 0.36, 0.216},
                                              { 0 , 0  , 0  , 0  , 0   , 0    }}
    #declare camera_z_distance = 25;
    #declare camera_y_height   = 1;
    #declare CL_set_string     = "#x^xxx"

//
  #break
  //
  #case(6)
// Vector kludge                                            
    #declare camera_z_distance = 50;
    #declare camera_y_height   = 0;
    #declare CL_set_string     = "#P|!_C(p_0 , p_1) = x";
  #break
  //
  #case(7)
// Double superscript                                           
    #declare camera_z_distance = 90;
    #declare camera_y_height   = 0;
    #declare CL_set_string     = "#Ca(OH)_2# |h #Ca^+^+ + 2OH^-";    // Notice the superscript ++ should be OK without letter_adjust
#end
//
#declare text_string = object{CL_rlp_make_text_string(CL_set_string,CL_tiny_space,CL_letter_adjust,CL_z1,
                                                      CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,CL_dimensions_out)  
                              pigment{rgb <0.9,0.9,0.9>}}
object{text_string translate <-CL_dimensions_out[0]/2,0,0>}
//
  ////
 //  end example  //
//_______________//


light_source{<0,20,-25>, 4 fade_power 2 fade_distance 10
  #if(0)
    area_light x*2,y*2,8,8
    jitter adaptive 2
    area_illumination
  #end
            }

light_source{<0,20,25>, 4 fade_power 2 fade_distance 10
  #if(0)
    area_light x*2,y*2,8,8
    jitter adaptive 2
    area_illumination
  #end
            }

camera{orthographic location<camera_z_distance/2,camera_y_height+camera_z_distance/4,-camera_z_distance> 
                    look_at <0,camera_y_height,0> 
                    angle 15}

//camera{orthographic location<0,0.9,-camera_z_distance> 
//                    look_at <0,0.9,0> 
//                    angle 15}
