/*
 
 //This file is licensed under the terms of the CC-LGPL
 
 CL_rlp_template_test.pov
 
 The idea for this file is you can use it as a template for the #macro calls.
 There are several other test files that give more extensive examples linking together several of the different #macros.
 See CL_rlp_fonts_symbols_test.pov for the range of fonts and symbols available.
  
 Read through the comments in CL_rlp_capital_letters_160519.inc for background and detailed instructions.
 
*/
//***************************************************************************************************************************************
//You will need this stuff in your .pov file
//***************************************************************************************************************************************
#version 3.7;
#global_settings{charset utf8 assumed_gamma 1.0}   // MUST USE utf8 for the character set, or you get s for spaces, amongst other things.
//
#include "colors.inc"
#include "rlp.inc"    // Sam Benge's excellent rounded linear prism #macros, available from the POVray Object Collection.
#include "CL_rlp_capital_letters_160714.inc" 
//
// Set up a load of globals that can be passed as arguments into all the routines.
//  
#declare char_type = 4; // 1 chamfered edge, 2 chamfered edge, rounded corners, 3 rounded edge, 4 rounded edge, rounded corners
// 
CL_rlp_make_text_string_set(char_type) // Defines CL_tiny_space,CL_small_space,CL_medium_space,CL_large_space,CL_huge_space,
//                                                CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
//                                                CL_dimensions_out, CL_debug_lines, CL_oint, CL_frac_numerator, CL_frac_denominator as globals 
//***************************************************************************************************************************************
// CHANGE THESE **************************************************************************************************************************
//***************************************************************************************************************************************
#declare CL_debug_lines = 1;  // 0 for no debug lines and messages, 1 for debug lines and messages,
#declare icase = 1;   // 1 - 17
//***************************************************************************************************************************************
//***************************************************************************************************************************************
//***************************************************************************************************************************************
//
// Make a few objects for use in later examples. Don't worry about these.         
//
#declare discriminant_dims   = array[4]{0,0,0,0};
#declare discriminant_obj    = object{CL_rlp_make_text_string("# b^2 - 4ac",CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,
                                                              CL_d_rad,CL_offs,CL_cham,CL_font_type,discriminant_dims)} 
#declare disc_surd_dims      = array[4]{0,0,0,0};
#declare disc_surd_obj       = object{CL_rlp_make_elastic_surd(CL_medium_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                               discriminant_obj,CL_medium_space,0,discriminant_dims,disc_surd_dims)}
#declare minusbpm_dims       = array[4]{0,0,0,0};
#declare minusbpm_obj        = object{CL_rlp_make_text_string("#-b |+ ",CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,
                                                              CL_d_rad,CL_offs,CL_cham,CL_font_type,minusbpm_dims)} 
//
#declare pisq_dims           = array[4]{0,0,0,0};
#declare pisq                = object{CL_rlp_make_text_string("#|p^2",CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,
                                                              CL_d_rad,CL_offs,CL_cham,CL_font_type,pisq_dims)} 
#declare six_dims            = array[4]{0,0,0,0};
#declare six                 = object{CL_rlp_make_text_string("#6",CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,
                                                              CL_d_rad,CL_offs,CL_cham,CL_font_type,six_dims)} 
#declare pisqbysix_dims      = array[4]{0,0,0,0};
#declare fraction_dimensions = array[2]{pisq_dims,six_dims};
#declare pisqbysix_obj       = object{CL_rlp_make_fraction(CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,pisq,six,
                                                           CL_medium_space,fraction_dimensions,pisqbysix_dims)}   
//
#declare nsq_dims            = array[4]{0,0,0,0};
#declare nsq                 = object{CL_rlp_make_text_string("#n^2",CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,
                                                              CL_d_rad,CL_offs,CL_cham,CL_font_type,nsq_dims)} 
#declare one_dims            = array[4]{0,0,0,0};
#declare one                 = object{CL_rlp_make_text_string("#1",CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,
                                                              CL_d_rad,CL_offs,CL_cham,CL_font_type,one_dims)} 
#declare onebynsq_dims       = array[4]{0,0,0,0};
#declare fraction_dimensions = array[2]{one_dims,nsq_dims};
#declare onebynsq_obj        = object{CL_rlp_make_fraction(CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,one,nsq,
                                                           CL_medium_space,fraction_dimensions,onebynsq_dims)}   
//
#declare series_dims         = array[4]{0,0,0,0};
#declare series_obj          = object{CL_rlp_make_sumprod(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                          onebynsq_obj,"","#n =1","#|8",CL_medium_space,1,0,onebynsq_dims,series_dims)} 
//
#declare square_bracket_dims = array[4]{0,0,0,0};
#declare square_bracket_obj  = object{CL_rlp_make_elastic_bracket_pair(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                       onebynsq_obj,CL_tiny_space,2,2,onebynsq_dims,square_bracket_dims)}
//******************************************************************************************************************************************************
// Start of the switch loop ****************************************************************************************************************************
//******************************************************************************************************************************************************
// Cases:
// 1)  CL_rlp_make_text_string               : converts a coded text STRING to a maths OBJECT. 
// 2)  CL_rlp_make_text_fraction             : takes two coded text STRINGS to make a fraction maths OBJECT.
// 3)  CL_rlp_make_fraction                  : takes two OBJECTS and constructs a fraction OBJECT with them.
// 4)  CL_rlp_make_text_function_fraction    : takes a front STRING, a numerator STRING, a denominator STRING and a back STRING (which can start with
//                                             ^ or #^ when it will be taken as a superscript), and turns them into a maths OBJECT with the fraction 
//                                             inside elastic brackets.
// 5)  CL_rlp_make_integral                  : takes either an integrand OBJECT or a STRING, STRINGS for the integration variable, 
//                                             upper and lower limits and returns an integral OBJECT. 
// 6)  CL_rlp_make_multiple_integrals        : takes an integrand OBJECT or STRING, arrays of STRINGS for the integration variables. 
//                                             (inner to outer) and for the limits (inner, lower to outer, upper in order) and returns an OBJECT
// 7)  CL_rlp_make_linesurfacevolume_integral: takes either an integrand object or a string, strings for the integration variasble and 
//                                             lower limit and returns an integral object.   
// 8)  CL_rlp_make_sumprod                   : takes either an inside OBJECT or a STRING plus lower and upper STRINGS and makes an 
//                                             inline or displayed sum or product OBJECT. 
// 9)  CL_rlp_make_elastic_surd              : takes an inner object and puts an elastic surd round it, possibly adding a pre-superscript of 3 or 4
// 10) CL_rlp_make_elastic_brackets          : Place a pair (not necessarily matched) elastic brackets around an object.
// 11) CL_rlp_make_superscript_subscript     : takes an OBJECT and places superscript and subscript STRINGS where they should be. 
// 12) CL_rlp_make_concatenate               : takes two objects and concatenates them into a single OBJECT.
// 13) CL_rlp_make_equation                  : takes two OBJECTS for the LHS and the RHS, and an OBJECT or a STRING for the relationship and 
//                                             forms an equation OBJECT, returning the position of the centre of the relationship to allow for 
//                                             accurate positioning without trial and error.
// 14) CL_rlp_make_stack                     : takes three STRINGS and produces a stack object with over- and under- strings in reduced font size.
// 15) CL_rlp_text_array                     : takes an array of text STRINGS and forms the OBJECT of the array.
// 16) CL_rlp_make_array                     : takes an array of OBJECTS and forms the OBJECT of the array.
// 17) CL_rlp_make_embellish                 : takes either an OBJECT or a STRING and adds a range of embellishments.
//
//*****************************************************************************************************************************************************
#switch(icase)
  #case(1)
//
// CL_rlp_make_text_string: converts a coded text string to a maths object 
// 
    #declare my_text_string         = "#x^-^$|,|,|,|!_i   |!|!";  //  is a quarter character, $ is a half character.
//                                                                    superscript before subscript ALWAYS. |, is -0.5, |! is -0.2 -ve space. 
//                                                                    The spaces at the back are to correct the bounding box.
//    #declare my_text_string         = "#(s^2 + a^2)^2";  
    #declare my_maths_object        = object{CL_rlp_make_text_string(my_text_string,CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,
                                                                     CL_d_rad,CL_offs,CL_cham,CL_font_type,CL_dimensions_out)} 
  #break
//
  #case(2)  
//
//  CL_rlp_make_text_fraction: takes two coded text strings to make a fraction maths object
//
    #declare numer_string           = "#f'(t)";
    #declare denom_string           = "#f(t)";   
    #declare letter_adjust_numer    = CL_letter_adjust;
    #declare letter_adjust_denom    = CL_letter_adjust;  
    #declare my_maths_object        = object{CL_rlp_make_text_fraction(CL_tiny_space,letter_adjust_numer,letter_adjust_denom,
                                                                       CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                       numer_string,denom_string,CL_medium_space,CL_dimensions_out)} 
//
  #break
//
  #case(3)  
//
// CL_rlp_make_fraction: takes two objects and constructs a fraction with them
//  
    #declare fraction_dimensions    = array[2]{pisq_dims,six_dims};
    #declare numerator_obj          = pisq;
    #declare denominator_obj        = six;
    #declare my_maths_object        = object{CL_rlp_make_fraction(CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,numerator_obj,denominator_obj,
                                                                  CL_medium_space,fraction_dimensions,CL_dimensions_out)}   
//
  #break
//
  #case(4)  
//
//  CL_rlp_make_text_function_fraction: takes a function/front string, a numerator string, a denominator string and a back string, 
//                                      and turns them into a maths object with the function argument being the fraction inside 
//                                      elastic brackets with possibly a back expression, which could be a superscript if it starts with ^ or #^.
//
    #local text_function_elements = array[4]{"#1 + ","|d#y","|d#x","#^2"}; 
//    #local text_function_elements = array[4]{"#b_n#sin","#2n|pt","#T",""};     
    #declare default_space          = CL_tiny_space;
    #declare letter_adjust_funct    = CL_letter_adjust;  // None of the strings are using letter_adjust.
    #declare letter_adjust_numer    = CL_letter_adjust;
    #declare letter_adjust_denom    = CL_letter_adjust;   
    #declare letter_adjust_back     = CL_letter_adjust;   
    #declare brace_type_left        = 1;    // 0 no bracket, 1 round, 2 square, 3 curly, 4 vertical bar, 5 langle/rangle  
    #declare brace_type_right       = 1;
    #declare space_around           = CL_medium_space;
    #declare horiz_space            = CL_medium_space;
    #declare back_adjust            = 0;    // Vertical adjustment to any back expression
    #declare my_maths_object        = object{CL_rlp_make_text_function_fraction(default_space,letter_adjust_funct,letter_adjust_numer,
                                                                                letter_adjust_denom,letter_adjust_back,
                                                                                CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                                text_function_elements,brace_type_left,brace_type_right,
                                                                                space_around,horiz_space,back_adjust,CL_dimensions_out)}  
//
  #break
//    
  #case(5)
//
// CL_rlp_make_integral: takes either an integrand object or a string, strings for the integration variasble, upper and lower limits
//                       and returns an integral  
//
    #declare integrand_object       =  0; // Won't be used as an object since we have a string.   
    #declare integrand_string       = "#f(t) #cos#(2n|pt/T)";
    #declare int_varb_string        = "#t";
    #declare low_limit_string       = "#0";
    #declare upp_limit_string       = "#T"; 
    #declare inline_disp            =  1;    // 0 for inline, 1 for displayed
    #declare int_letter_adjust      = CL_letter_adjust; // Letter adjustment for the integrand. None in this case.
    #declare default_letter_adjust  = CL_letter_adjust; // Should be no adjustment for the limits
    #declare front_space            = CL_medium_space;  // Space between the integral plus limits and the integrand
    #declare back_space             = CL_medium_space;  // Space between the integrand and the integration operator 
    #declare integrand_dims         = array[4]{0,0,0,0};
    #declare my_maths_object        = object{CL_rlp_make_integral(CL_tiny_space,int_letter_adjust,default_letter_adjust,
                                                                  CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                  integrand_object,integrand_string,int_varb_string,
                                                                  low_limit_string,upp_limit_string,
                                                                  front_space,back_space,inline_disp,integrand_dims,CL_dimensions_out)}                                                
//
  #break
//
  #case(6)
//
// CL_rlp_make_multiple_integrals: takes an integrand OBJECT or STRING, arrays of STRINGS for the integration variables (inner to outer)
//                                 and for the limits (inner, lower to outer, upper in order) and returns an OBJECT
//
    #declare integrand_part         = 0;
    #declare integrand_string       = "#f(x,y,z)";  
    #declare int_varb_array         = array[3]{"#z","#y","#x"};
    #declare sub_super_array        = array[6]{"#c_1(x,y)","#c_2(x,y)","#b_1(x)","#b_2(x)","#a_1","#a_2"};
    #declare front_space_array      = array[3]{CL_medium_space,-CL_medium_space,-CL_medium_space}; 
    #declare back_space             = CL_medium_space;
    #declare display_type           = 1; // 0 inline, 1 displayed
    #declare mult_int_level         = 3; // 1 single, 2 double, 3 triple   
    #declare integrand_dimensions   = array[4]{0,0,0,0};
    #declare CL_dimensions_out      = array[4]{0,0,0,0};
    #declare my_maths_object        = object{CL_rlp_make_multiple_integrals(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,
                                                                            CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                            integrand_part,integrand_string,int_varb_array,
                                                                            sub_super_array,front_space_array,back_space,
                                                                            display_type,mult_int_level,
                                                                            integrand_dimensions,CL_dimensions_out) }
//  
  #break
//
  #case(7)  
//
// CL_rlp_make_linesurfacevolume_integral: takes either an integrand object or a string, strings for the integration variasble and 
//                                         lower limit and returns an integral object.  
//  
    #declare integrand_part         = 0;
    #declare integrand_string       = "#|9.F";  // For volume
    #declare int_varb_string        = "#V";
    #declare sub_string             = "#V";  
    #declare front_space            = 0;
    #declare back_space             = CL_medium_space;
    #declare int_letter_adjust      = CL_letter_adjust; // Letter adjustment for the integrand. None in this case.
    #declare default_letter_adjust  = CL_letter_adjust; // Should be no adjustment for the limits
    #declare display_type           = 1;  // 0 for inline, 1 for displayed
    #declare integral_type          = 3;  // 1 for line, 2 for surface, 3 for volume.
    #declare vector_type            = 3;  // 1 for underlined, 2 for emboldened. For surface, 3 for dot n hat underlined, 4 for dot n emboldened.
    #declare oint                   = 0;  // 0 for oint, 1 for not oint. Ignored for volume.
    #declare integrand_dimensions   = array[4]{0,0,0,0};
    #declare vol_int_dimensions     = array[4]{0,0,0,0};
    #declare my_maths_object        = object{CL_rlp_make_linesurfacevolume_integral(CL_tiny_space,int_letter_adjust,default_letter_adjust,
                                                                                    CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                                    integrand_part,integrand_string,int_varb_string,sub_string,
                                                                                    front_space,back_space,display_type,integral_type,vector_type,oint,
                                                                                    integrand_dimensions,CL_dimensions_out)} 
  #break
//
  #case(8)   
//
// CL_rlp_make_sumprod: takes either an inside object object or a string plus lower and upper strings and makes an inline or displayed sum or product. 
//
    #declare inside_object          =  0;                     // Dummy object since we are using a string.
    #declare inside_string          = "#1/n^2";
    #declare low_limit_string       = "#n=1";
    #declare upp_limit_string       = "#|8";
    #declare display_type           =  0;                     // 0 for inline, 1 for display
    #declare sumprod_type           =  0;                     // 0 for sum, 1 for product
    #declare inside_dims            = array[4]{0,0,0,0};
    #declare my_maths_object        = object{CL_rlp_make_sumprod(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                 inside_object,inside_string,low_limit_string,upp_limit_string,CL_medium_space,
                                                                 display_type,sumprod_type,inside_dims,CL_dimensions_out)} 
//
  #break
//
  #case(9)   
//
// CL_rlp_make_elastic_surd: takes an inner object and puts an elastic surd round it, possibly adding a pre-superscript of 3 or 4
//
    #declare inner_part             = discriminant_obj;
    #declare inner_part_dims        = discriminant_dims;
    #declare surd_super             = 0; // Can be 0 for nothing, 3 or 4.
    #declare space_around           = CL_medium_space; 
    #declare my_maths_object        = object{CL_rlp_make_elastic_surd(CL_medium_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                      inner_part,space_around,surd_super,inner_part_dims,CL_dimensions_out)}
//
  #break
//
  #case(10)   
//
// CL_rlp_make_elastic_bracket_pair: Place a pair (not necessarily matched) elastic brackets around an object.
//
    #declare inner_part             = pisqbysix_obj;
    #declare space_around           = CL_tiny_space;
    #declare left_type              = 1;
    #declare right_type             = 1;
    #declare inner_part_dims        = pisqbysix_dims;
    #declare my_maths_object        = object{CL_rlp_make_elastic_bracket_pair(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                              inner_part,space_around,left_type,right_type,inner_part_dims,CL_dimensions_out)}
//
  #break
//
  #case(11)   
//
// CL_rlp_make_supersubscript: Place a pair of superscripts and subscripts above and below an object
//  
    #declare main_letter_adjust     = CL_letter_adjust;
    #declare main_part              = square_bracket_obj;
    #declare main_string            = "";
    #declare sub_string             = "#3"
    #declare super_string           = "#2"
    #declare script_space           = CL_medium_space;
    #declare sup_letter_adjust      = CL_letter_adjust;
    #declare sub_letter_adjust      = CL_letter_adjust;
    #declare sup_adjust             = 0; // You can adjust the superscript up and down, if you wish
    #declare main_dimensions        = square_bracket_dims;
    #declare my_maths_object        = object{CL_rlp_make_supersubscript(CL_tiny_space,main_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                        main_part,main_string,sub_string,super_string,script_space,
                                                                        sup_letter_adjust,sub_letter_adjust,sup_adjust,main_dimensions,CL_dimensions_out)} 
//
  #break 
//
  #case(12)   
//
// CL_rlp_make_concatenate: take two objects and concatenate them.
//
    #declare part_dims              = array[2]{minusbpm_dims,disc_surd_dims};
    #declare space_between          = CL_medium_space;
    #declare my_maths_object        = object{CL_rlp_make_concatenate(minusbpm_obj,disc_surd_obj,space_between,part_dims,CL_dimensions_out)} 
//
  #break
//
  #case(13)   
//
//  CL_rlp_make_equation: takes LHS and RHS OBJECTS and a relationship OBJECT or STRING and makes an equation object.
//                                                       
    #declare lhs_object             = pisqbysix_obj;
    #declare rhs_object             = series_obj;
    #declare part_dims              = array[2]{pisqbysix_dims,series_dims}; 
    #declare relation_object        = 0;
    #declare relation_string        = " = ";
    #declare space_around           = CL_medium_space; 
    #declare my_maths_object        = object{CL_rlp_make_equation(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                  lhs_object,rhs_object,relation_object,relation_string,
                                                                  space_around,part_dims,CL_dimensions_out)} 
    #declare relation_middle        = CL_dimensions_out[2]; // This is the x coord of the middle of the relationship, so you can line up, e.g. equals signs.
//
  #break  
//
  #case(14)
//
//  CL_rlp_make_stack: Takes three strings and puts them as a stack
//
    #declare relation_string        = " |h ";
    #declare under_string           = "#k_2";  
    #declare over_string            = "#k_1";                       
    #declare under_adjust           =  0;               
    #declare over_adjust            =  0;
    #declare my_maths_object        = object{CL_rlp_make_stack(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                               relation_string,under_string,over_string,under_adjust,over_adjust,CL_dimensions_out) }      
//
  #break
//
  #case(15)
//
//  CL_rlp_make_bracketed_text_array: take an array of strings, form the objects and arrange them in an array, with elastic brackets.
//   
    #declare array_nrows            =  3;
    #declare array_ncols            =  3;  
    #declare text_array_elements    = array[3][3]{{"#-1","#2","#y^2"},{"#0","#x - y","#1"},{"#6","#7","#x"}};  
    #declare array_alignment        = "rcc";
    #declare left_bracket_type      =  1; // 0 for no bracket, 1 round, 2 square, 3 curly, 4 vertical bar, 5 langle/rangle
    #declare right_bracket_type     =  1; 
    #declare space_around           = CL_medium_space;
    #declare horiz_space            = CL_large_space;
    #declare vert_space             = CL_large_space;
    #declare my_maths_object        = object{CL_rlp_make_bracketed_text_array(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                              array_nrows,array_ncols,text_array_elements,array_alignment,
                                                                              left_bracket_type,right_bracket_type,space_around,horiz_space,vert_space,
                                                                              CL_dimensions_out)}     
//  
  #break
//
  #case(16)
//
// CL_make_array: takes an array of objects and arranges them into an array object. No elastic brackets by default.
//
    #declare inner_parts            = array[2][2];
    #declare inner_dimensions       = array[2][2];
//
// Set up the array of objects and the array of object dimensions.
//
    #declare inner_parts[0][0]      =  object{CL_rlp_make_text_fraction(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                        "#|j^2|f","#|jx^2",CL_medium_space,CL_dimensions_out)}
    #declare inner_dimensions[0][0] =  CL_dimensions_out; 
//
    #declare inner_parts[0][1]      =  object{CL_rlp_make_text_fraction(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                        "#|j^2|f","#|jx|jy",CL_medium_space,CL_dimensions_out)}
    #declare inner_dimensions[0][1] =  CL_dimensions_out; 
//
    #declare inner_parts[1][0]      =  object{CL_rlp_make_text_fraction(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                        "#|j^2|f","#|jy|jx",CL_medium_space,CL_dimensions_out)}
    #declare inner_dimensions[1][0] =  CL_dimensions_out; 
//
    #declare inner_parts[1][1]      =  object{CL_rlp_make_text_fraction(CL_tiny_space,CL_letter_adjust,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                        "#|j^2|f","#|jy^2",CL_medium_space,CL_dimensions_out)}
    #declare inner_dimensions[1][1] =  CL_dimensions_out; 
//  
    #declare array_obj              =  object{CL_rlp_make_array(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                inner_parts,"cc",CL_medium_space,CL_large_space,CL_large_space,
                                                                inner_dimensions,CL_dimensions_out) }
    #declare array_dimensions       = CL_dimensions_out;
//
// Put the elastic brackets around it.
//
    #declare space_around           = CL_tiny_space;
    #declare left_type              = 1;
    #declare right_type             = 1;
    #declare my_maths_object        = object{CL_rlp_make_elastic_bracket_pair(CL_tiny_space,CL_letter_adjust,CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                              array_obj,space_around,left_type,right_type,array_dimensions,CL_dimensions_out)} 
//
  #break
//
  #case(17)
//
// CL_rlp_make_embellish: It's complicated. More help in CL_rlp_embellish_test.pov
//
    #declare letter_adjust_main     = CL_letter_adjust;
    #declare letter_adjust_over     = CL_letter_adjust;
    #declare letter_adjust_under    = CL_letter_adjust;
    #declare main_obj               = 0;      // Dummy, since we are using a string
    #declare main_string            = "#1 + 3 + 5 + 7 + 9 + 11 + 13 = 49"
    #declare over_embellish_type    = 6;
    #declare under_embellish_type   = 9;
    #declare over_string            = "#21 = 3|*7";
    #declare under_string           = "#49 = 7|*7";
    #declare outer_box              = 1;
    #declare embellish_adjust       = array[5][4]{{ 0.67,0.67, -3.5, 0.5},  // Over text      : add_scale_x, add_scale_y , shift_x, shift_y
                                                  {-24.5, 1  ,  8  , 0.5},  // Over embellish : add_dist_x , add_scale_y , shift_x, shift_y
                                                  { -5.5, 1  ,  0  ,-0.5},  // Under embellish: add_dist_x , add_scale_y , shift_x, shift_y
                                                  { 0.67,0.67,-2.0 ,  0 },  // Under text     : add_scale_x, add_scale_y , shift_x, shift_y
                                                  {  1  , 0  , 4.0 , 6.5}}; // Outer box      : add_to_gap , add_to_thick, out_rad, inn_rad
// 
// CL_embellish_adjust is a 5 by 4 array of zeros which is what would usually be used.
//
// Over and under text are scaled by 0.6 then scaled by (1 + add_scale_x) or (1 + add_scale_y), so add_scale_x,y = 0.67 restores them to full size.
//
// Over and under embellishments are often scaled across the whole width of the main object. This apparent width can be changed with add_dist_x.
// Thus, if you shorten with add_dist_x = -5, you need shift_x = +2.5 to keep the embellishment centred.
//
// The default y scale for the embellishment is 1, which is added to by add_scale_y 
//
// When the embellishment is a box, the meanings are as for the outer box. Default gap is 0.3, Default thick is 0.3. These won't be reduced 
// below 0.1 however negative add_to_gap and add_to_thick are. 
//
    #declare dimensions_in          = array[4]{0,0,0,0};
    #declare my_maths_object        = object{CL_rlp_make_embellish(CL_tiny_space,letter_adjust_main,letter_adjust_over,letter_adjust_under,
                                                                   CL_z1,CL_z2,CL_d_rad,CL_offs,CL_cham,CL_font_type,
                                                                   main_obj,main_string,over_embellish_type,under_embellish_type,
                                                                   over_string,under_string,outer_box,embellish_adjust,dimensions_in,
                                                                   CL_dimensions_out)}  
// End of the switch loop
#end
//
object{my_maths_object translate <-CL_dimensions_out[0]/2,0,0> pigment{rgb 1} finish{ambient 0 specular 1}}  
//
//cylinder{<0,-20,0> <0,20,0> 0.2 pigment{Green}}
  ////
 //  end example  //
//_______________//
light_source{<0,20,-25>, 4 fade_power 2 fade_distance 10
  #if(0)
    area_light x*2,y*2,8,8
    jitter adaptive 2
    area_illumination
  #end
            }
//
camera{orthographic 
       location<0,(CL_dimensions_out[1]-CL_dimensions_out[3])/2,-4*max(2*(CL_dimensions_out[1]+CL_dimensions_out[3]),CL_dimensions_out[0])> 
       look_at <0,(CL_dimensions_out[1]-CL_dimensions_out[3])/2,0> 
       angle 15
      }

